freegs package
==============

.. automodule:: freegs
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   freegs.boundary
   freegs.coil
   freegs.control
   freegs.critical
   freegs.divgeo
   freegs.dump
   freegs.equilibrium
   freegs.fieldtracer
   freegs.filament_coil
   freegs.geqdsk
   freegs.gradshafranov
   freegs.jtor
   freegs.machine
   freegs.multi_coil
   freegs.multigrid
   freegs.optimise
   freegs.optimiser
   freegs.picard
   freegs.plotting
   freegs.polygons
   freegs.pre_calc_coil
   freegs.quadrature
   freegs.shaped_coil
   freegs.test_critical
   freegs.test_equilibrium
   freegs.test_filament_coil
   freegs.test_jtor
   freegs.test_linearsolve
   freegs.test_machine
   freegs.test_optimise
   freegs.test_optimiser
   freegs.test_polygons
   freegs.test_quadrature
   freegs.test_readwrite
   freegs.test_sensors
   freegs.test_shaped_coil
